@@ -2,6 +2,5 @@ from django.apps import AppConfig
 
 
 class DittoLastfmConfig(AppConfig):
-    name = 'ditto.lastfm'
-    verbose_name = 'Ditto Last.fm'
-
+    name = "ditto.lastfm"
+    verbose_name = "Ditto Last.fm"
