@@ -2,6 +2,5 @@ from django.apps import AppConfig
 
 
 class DittoTwitterConfig(AppConfig):
-    name = 'ditto.twitter'
+    name = "ditto.twitter"
     verbose_name = "Ditto Twitter"
-
